Index: chrome/browser/extensions/crashed_extension_infobar.h |
diff --git a/chrome/browser/extensions/crashed_extension_infobar.h b/chrome/browser/extensions/crashed_extension_infobar.h |
index 1508ae5246545f9cefd6d30610734f3f92d9d356..619561c95e261842b279d9fb3ce5f9d0e8848a5a 100644 |
--- a/chrome/browser/extensions/crashed_extension_infobar.h |
+++ b/chrome/browser/extensions/crashed_extension_infobar.h |
@@ -12,7 +12,7 @@ |
#include "chrome/browser/tab_contents/infobar_delegate.h" |
class Extension; |
-class ExtensionsService; |
+class ExtensionService; |
class SkBitmap; |
// This infobar will be displayed when an extension process crashes. It allows |
@@ -21,9 +21,9 @@ class CrashedExtensionInfoBarDelegate : public ConfirmInfoBarDelegate { |
public: |
// |tab_contents| should point to the TabContents the infobar will be added |
// to. |extension| should be the crashed extension, and |extensions_service| |
// the ExtensionsService which manages that extension. |
CrashedExtensionInfoBarDelegate(TabContents* tab_contents, |
- ExtensionsService* extensions_service, |
+ ExtensionService* extensions_service, |
const Extension* extension); |
const std::string extension_id() { return extension_id_; } |
@@ -41,7 +41,7 @@ class CrashedExtensionInfoBarDelegate : public ConfirmInfoBarDelegate { |
virtual bool Accept(); |
private: |
- ExtensionsService* extensions_service_; |
+ ExtensionService* extensions_service_; |
const std::string extension_id_; |
const std::string extension_name_; |
@@ -21,9 +21,9 @@ class CrashedExtensionInfoBarDelegate : public ConfirmInfoBarDelegate { |
// |tab_contents| should point to the TabContents the infobar will be added |
// to. |extension| should be the crashed extension, and |extensions_service| |
- // the ExtensionsService which manages that extension. |
+ // the ExtensionService which manages that extension. |
CrashedExtensionInfoBarDelegate(TabContents* tab_contents, |